local offst_x    = 0  -- set offset from right border
local offst_y    = 0  -- set offset from top border

local mmap_pos_x = offst_x + 5  -- set minimap position from right offset
local mmap_pos_y = offst_y + 30 -- set minimap position from top offset
local lctn_pos_x = offst_x + 5  -- set location bar position from right offset 
local lctn_pos_y = offst_y + 5  -- set location bar position from top offset
local crd_pos_x  = offst_x + 50 -- set coordinates position from right offset
local crd_pos_y  = offst_y + 28 -- set coordinates position from top offset
local clc_pos_x  = offst_x + 52 -- set clock position from right offset
local clc_pos_y  = offst_y + 160 -- set clock position from top offset
local scl        = 1  -- set scale of minimap
local opacity    = 1  -- set minimap transparency from 0 to 1

local lctn_bar_enable = 1 -- enable (1) or disable (0) location bar
local crd_bar_enable  = 1 -- enable (1) or disable (0) coord bar
 
function GetMinimapShape() -- set square shape
   return "SQUARE" 
end 

local module = CreateFrame("Frame", nil, UIParent) -- main frame of our mod
local lctn_bar = CreateFrame("Frame", lctn_bar, UIParent) -- location bar frame
local crd_bar = CreateFrame("Frame", coord, UIParent) -- coordination bar frame
local clc_bar = CreateFrame("Frame", clc, UIParent)

module:RegisterEvent("PLAYER_LOGIN") -- register events
module:RegisterEvent("ZONE_CHANGED_NEW_AREA")

local locat_setup = function() -- define parameters of location bar
   lctn_bar.txt = lctn_bar:CreateFontString(nil,"OVERLAY") -- define text settings, create text frame of location bar
   lctn_bar.txt:SetPoint("CENTER",lctn_bar)
   lctn_bar.txt:SetFont("Interface\\AddOns\\LnS_Minimap\\Res\\stat_font.ttf",14,nil) -- setup font settings (font, size)
   lctn_bar.txt:SetShadowOffset(1,-1)
   lctn_bar:SetWidth(140) -- set width of location bar
   lctn_bar:SetHeight(18) -- set height of location bar
   lctn_bar:SetScale(scl) -- set scale of location bar. same as minimap by default, but can be defined by user.
   lctn_bar:SetPoint("TOPRIGHT", UIParent, "TOPRIGHT", -lctn_pos_x, -lctn_pos_y) -- placing our frame
   lctn_bar:SetBackdrop({ -- make backdrop
      bgFile = "Interface\\AddOns\\LnS_Minimap\\Res\\backdrop", 
      insets = {left = -2, right = -2, top = -2, bottom = -2},})
   lctn_bar:SetFrameStrata("BACKGROUND") 
   lctn_bar:SetBackdropColor(0,0,0,0.9);    
   lctn_bar:SetBackdropBorderColor(1,1,1,1)
   if lctn_bar_enable == 1 then -- define enable/disable
   lctn_bar:Show()
   else
   lctn_bar:Hide()
   end
end

local coord_setup = function()
   crd_bar.txt = crd_bar:CreateFontString(nil,"OVERLAY")
   crd_bar.txt:SetPoint("CENTER",crd_bar)
   crd_bar.txt:SetFont("Interface\\AddOns\\LnS_Minimap\\Res\\stat_font.ttf",10,nil)
   crd_bar.txt:SetShadowOffset(1,-1)
   crd_bar.txt:SetTextColor(1,1,1)
   crd_bar:SetWidth(50)       
   crd_bar:SetHeight(14)
   crd_bar:SetScale(scl)
   crd_bar:SetFrameLevel(4)
   crd_bar:SetPoint("TOPRIGHT", UIParent, "TOPRIGHT", -crd_pos_x, -crd_pos_y)
   crd_bar:SetBackdrop({
      bgFile = "Interface\\AddOns\\LnS_Minimap\\Res\\backdrop", 
      insets = {left = -2, right = -2, top = -2, bottom = -2},})
   crd_bar:SetFrameStrata("BACKGROUND") 
   crd_bar:SetBackdropColor(0,0,0,0.9);    
   crd_bar:SetBackdropBorderColor(1,1,1,1)
end

local clock_setup = function()
   clc_bar.txt = clc_bar:CreateFontString(nil,"OVERLAY")
   clc_bar.txt:SetPoint("LEFT",clc_bar,"LEFT",0,0)
   clc_bar.txt:SetFont("Interface\\AddOns\\LnS_Minimap\\Res\\stat_font.ttf",10,nil)
   clc_bar.txt:SetShadowOffset(1,-1)
   clc_bar.txt:SetTextColor(1,1,1)
   clc_bar:SetWidth(45)       
   clc_bar:SetHeight(14)
   clc_bar:SetScale(scl)
   clc_bar:SetFrameLevel(4)
   clc_bar:SetPoint("TOPRIGHT", UIParent, "TOPRIGHT", -clc_pos_x, -clc_pos_y)
   clc_bar:SetBackdrop({
      bgFile = "Interface\\AddOns\\LnS_Minimap\\Res\\backdrop", 
      insets = {left = -2, right = -2, top = -2, bottom = -2},})
   clc_bar:SetFrameStrata("BACKGROUND") 
   clc_bar:SetBackdropColor(0,0,0,0.9);    
   clc_bar:SetBackdropBorderColor(1,1,1,1)
end

module.on_update = function(self,elsp) -- update information
   self.update = self.update + elsp
   if(self.update > self.interval) then
   local location = GetMinimapZoneText()
   lctn_bar.txt:SetText(location)
   self.update = 0;
   local pvpType = GetZonePVPInfo();
   if ( pvpType == "sanctuary" ) then
    	lctn_bar.txt:SetTextColor(0.41, 0.8, 0.94);
   elseif ( pvpType == "arena" ) then
		lctn_bar.txt:SetTextColor(1.0, 0.1, 0.1);
   elseif ( pvpType == "friendly" ) then
		lctn_bar.txt:SetTextColor(0.1, 1.0, 0.1);
   elseif ( pvpType == "hostile" ) then
		lctn_bar.txt:SetTextColor(1.0, 0.1, 0.1);
   elseif ( pvpType == "contested" ) then
		lctn_bar.txt:SetTextColor(1.0, 0.7, 0.0);
   else
		lctn_bar.txt:SetTextColor(NORMAL_FONT_COLOR.r, NORMAL_FONT_COLOR.g, NORMAL_FONT_COLOR.b);
   end
   local posx, posy = GetPlayerMapPosition("player")
   if (posx == 0 and posy == 0) or crd_bar_enable == 0 then
   crd_bar:Hide()
   elseif (posx > 0 or posy > 0) and crd_bar_enable == 1 then
   crd_bar:Show()
   crd_bar.txt:SetText((floor((posx*1000)+0.5)/10).." | "..(floor((posy*1000)+0.5)/10))
   end
   location = GetMinimapZoneText()
   local clck = strsub(date(),-8,-4)
   clc_bar.txt:SetText(clck)
   TimeManagerClockButton_Hide()
   end
end

module.ZONE_CHANGED_NEW_AREA = function(self)
   SetMapToCurrentZone()
end

local pin = function(pframe,pinframe,scale,anchor,anchor2,off_x,off_y) -- pin module
   pinframe:SetScale(scale);
   pinframe:ClearAllPoints();
   pinframe:SetPoint(anchor,pframe,anchor2,off_x,off_y)  
end

module.PLAYER_LOGIN = function(self)
   module.update    =  0.0
   module.interval  =  0.1 -- define update time in seconds
   locat_setup(lctn_bar) -- setup location frame
   coord_setup(crd_bar) -- setup coord frame
   clock_setup(clc_bar) -- setup clock frame
   
   module:SetScript("OnUpdate",module.on_update)

   Minimap:EnableMouseWheel(true) -- enable mouse-scrolling over minimap for changing zoom
   Minimap:SetScript("OnMouseWheel", function() if(arg1 > 0) then Minimap_ZoomIn() else Minimap_ZoomOut() end end)
   
   Minimap:SetMaskTexture("Interface\\AddOns\\LnS_Minimap\\Res\\minimap_mask") -- set mask of our minimap
   
   self:SetParent(Minimap) -- set backdrop of our minimap, and now it's look perfectly (in my opinion :) )
   self:SetFrameLevel(1)
   self:SetBackdrop({ 
      bgFile = "Interface\\AddOns\\LnS_Minimap\\Res\\backdrop",
      insets = {left = -2, right = -2, top = -2, bottom = -2},})
   self:SetBackdropColor(0,0,0)
   self:SetAllPoints(Minimap)

   MiniMapMailBorder:SetTexture()  
   MiniMapBattlefieldBorder:SetTexture()
   MiniMapTrackingButtonBorder:SetTexture()
   MiniMapTrackingBackground:Hide()   
   MiniMapTrackingIconOverlay:SetAlpha(0)
   GameTimeFrame:SetFrameLevel(5)
   
   module:ZONE_CHANGED_NEW_AREA()
   module:SetAlpha(opacity)
   lctn_bar:SetAlpha(opacity)
   crd_bar:SetAlpha(opacity)
   Minimap:SetAlpha(opacity)
   
   pin(Minimap,MiniMapTracking,0.8,"TOPLEFT","TOPLEFT",-4,4)
   pin(Minimap,MiniMapBattlefieldFrame,0.9,"BOTTOMLEFT","BOTTOMLEFT",-3,-3)
   pin(Minimap,MiniMapMailFrame,1,"TOPRIGHT","TOPRIGHT",4,4)
   pin(clc_bar,GameTimeFrame,0.5,"RIGHT","RIGHT",10,0)
end

Minimap:ClearAllPoints()
Minimap:SetPoint("TOPRIGHT", UIParent, "TOPRIGHT", -mmap_pos_x,-mmap_pos_y) -- places our minimap at place. if needed, "TOPRIGHT" can be replaced "BOTTOMRIGHT", etc.
Minimap:SetScale(scl) --  sets scale of minimap, depending on settings

-- that block hides blizzard borders, buttons, etc.
local zero = function()  end
local _G   = getfenv(0)

local hide_frame = function(bframe)
   bframe.Show = zero
   bframe:Hide()
end

local blizz_frames = 
   {
   _G["MinimapBorder"], 
   _G["MinimapZoomIn"], 
   _G["MinimapZoomOut"],
   _G["MinimapZoneText"],
   _G["MinimapNorthTag"],
   _G["MinimapBorderTop"],
   _G["MinimapToggleButton"],
   _G["MinimapZoneTextButton"],
   _G["MiniMapWorldMapButton"],
   _G["MiniMapMeetingStoneFrame"],
   _G["MiniMapVoiceChatFrame"],
   _G["BattlegroundShine"],
   }

for ndx,bframe in pairs(blizz_frames)  do hide_frame(bframe) end

module:SetScript("OnEvent", function(self, event, ...) self[event](self, event, ...) end)

-- add slash command for reload ui
SlashCmdList['RELOADUI'] = function() ReloadUI() end
SLASH_RELOADUI1 = '/rl'